Module: Microsandbox::Cloud
- Defined in:
- lib/microsandbox/cloud.rb,
lib/microsandbox/cloud/version.rb
Defined Under Namespace
Classes: Error
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
-
.hello ⇒ Object
Provide a tiny smoke-test API while keeping the placeholder honest about not shipping cloud client behavior yet.
Class Method Details
.hello ⇒ Object
Provide a tiny smoke-test API while keeping the placeholder honest about not shipping cloud client behavior yet.
13 14 15 |
# File 'lib/microsandbox/cloud.rb', line 13 def hello "hello from microsandbox-cloud" end |